@@ -1,25 +1,31 @@
 package Sys::Info::Base;
 use strict;
+use warnings;
 use vars qw( $VERSION );
 use IO::File;
 use Carp qw( croak );
 use File::Spec;
 use Sys::Info::Constants qw( :date OSID );
+use constant DRIVER_FAIL_MSG => q{Operating system identified as: '%s'. }
+                              . q{Native driver can not be loaded: %s. }
+                              . q{Falling back to compatibility mode};
+use constant YEAR_DIFF => 1900;
 
-$VERSION = '0.72';
+$VERSION = '0.73';
 
 my %LOAD_MODULE; # cache
+my %UNAME;       # cache
 
 sub load_subclass { # hybrid: static+dynamic
     my $self     = shift;
-    my $template = shift || croak "Template missing for load_subclass()";
+    my $template = shift || croak 'Template missing for load_subclass()';
     my $class;
 
-    eval { $class = $self->load_module( sprintf $template, OSID ); };
+    my $eok = eval { $class = $self->load_module( sprintf $template, OSID ); };
 
-    if ( $@ ) {
-        warn sprintf( "Operating system identified as: '%s'. %s. "
-                     ."Falling back to compatibility mode", OSID, $@ );
+    if ( $@ || ! $eok ) {
+        my $msg = sprintf DRIVER_FAIL_MSG, OSID, $@;
+        warn "$msg\n";
         $class = $self->load_module( sprintf $template, 'Unknown' );
     }
 
@@ -28,18 +34,19 @@ sub load_subclass { # hybrid: static+dynamic
 
 sub load_module {
     my $self  = shift;
-    my $class = shift || croak "Which class to load?";
-    croak "Invalid class name: $class" if ref $class;
+    my $class = shift || croak 'Which class to load?';
     return $class if $LOAD_MODULE{ $class };
+    croak "Invalid class name: $class" if ref $class;
     (my $check = $class) =~ tr/a-zA-Z0-9_://d;
     croak "Invalid class name: $class" if $check;
-    my @raw_file = split /::/, $class;
-    return $class if exists $INC{ join('/', @raw_file).".pm" };
+    my @raw_file = split /::/xms, $class;
+    my $inc_file = join( q{/}, @raw_file) . '.pm';
+    return $class if exists $INC{ $inc_file };
     my $file = File::Spec->catfile( @raw_file ) . '.pm';
-    (my $inc_file = $file) =~ tr///;
-    eval { require $file; };
-    croak "Error loading $class: $@" if $@;
+    my $eok = eval { require $file; };
+    croak "Error loading $class: $@" if $@ || ! $eok;
     $LOAD_MODULE{ $class } = 1;
+    $INC{ $inc_file } = $file;
     return $class;
 }
 
@@ -50,7 +57,7 @@ sub trim {
     return $str if not $str;
     $str =~ s{ \A \s+    }{}xms;
     $str =~ s{    \s+ \z }{}xms;
-    $str;
+    return $str;
 }
 
 sub slurp { # fetches all data inside a flat file
@@ -58,13 +65,13 @@ sub slurp { # fetches all data inside a flat file
     my $file   = shift;
     my $msgerr = shift || 'I can not open file %s for reading: ';
     my $FH     = IO::File->new;
-       $FH->open($file) or croak sprintf($msgerr, $file) . $!;
-    my $slurped;
-    SLURP_SCOPE: {
+    $FH->open( $file ) or croak sprintf($msgerr, $file) . $!;
+    my $slurped = do {
        local $/;
-       chomp($slurped = <$FH>);
-    }
-    close  $FH;
+       my $rv = <$FH>;
+       $rv;
+    };
+    $FH->close;
     return $slurped;
 }
 
@@ -73,29 +80,29 @@ sub read_file {
     my $file   = shift;
     my $msgerr = shift || 'I can not open file %s for reading: ';
     my $FH     = IO::File->new;
-       $FH->open($file) or die sprintf($msgerr, $file) . $!;
+    $FH->open( $file ) or croak sprintf( $msgerr, $file ) . $!;
     my @flat   = <$FH>;
-    close  $FH;
+    $FH->close;
     return @flat;
 }
 
 sub date2time { # date stamp to unix time stamp conversion
     my $self   = shift;
-    my $stamp  = shift || die "No date input specified!";
+    my $stamp  = shift || croak 'No date input specified';
     my($i, $j) = (0,0); # index counters
     my %wdays  = map { $_ => $i++ } DATE_WEEKDAYS;
     my %months = map { $_ => $j++ } DATE_MONTHS;
-    my @junk   = split /\s+/, $stamp;
-    my $reg    = join    '|', keys %wdays;
+    my @junk   = split /\s+/xms, $stamp;
+    my $reg    = join q{|}, keys %wdays;
 
     # remove until ve get a day name
     while ( @junk && $junk[0] !~ m{ \A ($reg) \z }xmsi ) {
        shift @junk;
     }
-    return '' if ! @junk;
+    return q{} if ! @junk;
 
     my($wday, $month, $mday, $time, $zone, $year) = @junk;
-    my($hour, $min, $sec)                         = split /\:/, $time;
+    my($hour,   $min, $sec)                       = split /:/xms, $time;
 
     require POSIX;
     my $unix =  POSIX::mktime(
@@ -104,7 +111,7 @@ sub date2time { # date stamp to unix time stamp conversion
                     $hour,
                     $mday,
                     $months{$month},
-                    $year - 1900,
+                    $year - YEAR_DIFF,
                     $wdays{$wday},
                     DATE_MKTIME_YDAY,
                     DATE_MKTIME_ISDST,
@@ -113,6 +120,17 @@ sub date2time { # date stamp to unix time stamp conversion
     return $unix;
 }
 
+sub uname {
+    my $self = shift;
+    %UNAME   = do {
+        require POSIX;
+        my %u;
+        @u{ qw( sysname nodename release version machine ) } = POSIX::uname();
+        %u;
+    } if ! %UNAME;
+    return { %UNAME };
+}
+
 1;
 
 __END__
@@ -133,8 +151,8 @@ Sys::Info::Base - Base class for Sys::Info
 
 =head1 DESCRIPTION
 
-This document describes version C<0.72> of C<Sys::Info::Base>
-released on C<3 May 2009>.
+This document describes version C<0.73> of C<Sys::Info::Base>
+released on C<14 January 2010>.
 
 Includes some common methods.
 
@@ -169,18 +187,26 @@ Caches all contents of C<FILE> into an array and then returns it.
 
 Converts C<DATE_STRING> into unix timestamp.
 
+=head2 uname
+
+Returns a hashref built from C<POSIX::uname>.
+
+=head1 SEE ALSO
+
+L<Sys::Info>.
+
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
