@@ -1,33 +1,34 @@
 package Sys::Info::Device::CPU;
 use strict;
+use warnings;
+use vars qw( $VERSION );
 use subs qw(hyper_threading ht);
-use vars qw( $VERSION @ISA   );
 use base qw( Sys::Info::Base );
 use Sys::Info::Constants qw( OSID );
 use Carp qw( croak );
+use base __PACKAGE__->load_subclass('Sys::Info::Driver::%s::Device::CPU');
 
-$VERSION = '0.72';
+$VERSION = '0.73';
 
 BEGIN {
-    push @ISA, __PACKAGE__->load_subclass('Sys::Info::Driver::%s::Device::CPU');
     # define aliases
     *ht = \&hyper_threading;
 }
 
 sub new {
-    my $class = shift;
-    my %opt   = scalar(@_) % 2 ? () : (@_);
-    my $self  = {
+    my($class, @args) = @_;
+    my %opt  = @args % 2 ? () : @args;
+    my $self = {
         %opt,
         META_DATA => undef,
     };
     bless $self, $class;
-    $self;
+    return $self;
 }
 
 sub count {
     my $self = shift;
-    my $id   = shift || '';
+    my $id   = shift || q{};
     my @cpu  = $self->identify;
     if ( $id ) {
         croak "Parameter to count($id) if bogus" if $id ne 'cores';
@@ -62,7 +63,7 @@ sub hyper_threading {
 sub speed {
     my $self = shift;
     my @cpu  = $self->identify;
-    return if !@cpu || !ref($cpu[0]);
+    return if !@cpu || !ref $cpu[0];
     return $cpu[0]->{speed};
 }
 
@@ -79,13 +80,13 @@ sub _serve_from_cache {
     my $self    = shift;
     my $context = shift;
     return if not defined $context; # void context
-    croak "Can not happen: META_DATA is empty" if not $self->{META_DATA};
+    croak 'Can not happen: META_DATA is empty' if not $self->{META_DATA};
     return @{ $self->{META_DATA} } if $context;
     # scalar context
     my @cpu = @{ $self->{META_DATA} };
     # OK for single processor ("name" will be same)
     my $count = @cpu;
-    my $name  = $cpu[0] ? $cpu[0]->{name} : '';
+    my $name  = $cpu[0] ? $cpu[0]->{name} : q{};
     return $name if ! $count || $count == 1;
     return "$count x $name";
 }
@@ -114,8 +115,8 @@ Example:
 
 =head1 DESCRIPTION
 
-This document describes version C<0.72> of C<Sys::Info::Device::CPU>
-released on C<3 May 2009>.
+This document describes version C<0.73> of C<Sys::Info::Device::CPU>
+released on C<14 January 2010>.
 
 Collects and returns information about the Central Processing Unit
 (CPU) on the host machine.
@@ -213,20 +214,20 @@ otherwise.
 
 =head1 SEE ALSO
 
-L<Sys::Info>, L<Sys::Info::OS>.
+L<Sys::Info>, L<Sys::Info::OS>, L<Sys::Info::Device>.
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
